#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# bulkAttachStores.py - Bulk attach standard archiv stores under a 
#                       given directory
#
# Copyright (c) 2012 MailStore Software GmbH
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

# MailStore Management API connection settings
USER = "admin"
PASSWORD = "admin"
HOST = "localhost"
PORT = 8463

# Path where archives stores are located
path = "C:\Mailarchive"

# Requested state of newly attached archive stores
# For possible values, see "CreateStore" command at 
# http://en.help.mailstore.com/MailStore_Server_Management_API_Commands 
state = "normal"

################### DON'T CHANGE ANYTHING BELOW THIS LINE ###################
import sys, os
from mailstoreapi import ManagementAPI

# Connect to MailStore Management API
api = ManagementAPI(USER, PASSWORD, HOST, PORT)

def attachDirectory(path):
    # Walk through given path...
    for e in os.listdir(path):
        p = os.path.join(path, e)
        # ...and try to attach subdirectory
        if os.path.isdir(p):
            api.AttachStore(name=e, databasePath=p, requestedState=state)
            print ("[ATTACHED] Name: " + e + ", Path: " + p + ", State: " + state)
            
            
if __name__ == '__main__':   
    # Check if path is given and valid
    if not path:
        raise Exception("No or non-existing path given")

    # Attach all archive stores under given path   
    attachDirectory(path)
