#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# bulkUpdatePermissions.py - Bulk update permissions for all but admin user
#
# Copyright (c) 2012 MailStore Software GmbH
# 
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
# 
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

# MailStore Management API connection settings
USER = "admin"
PASSWORD = "admin"
HOST = "localhost"
PORT = 8463

# Define new privileges 
# For possible values, see "CreateUser" command at
# http://en.help.mailstore.com/MailStore_Server_Management_API_Commands 
privileges = "login,export,changePassword,modifyExportProfiles,modifyArchiveProfiles"
privilegesOnFolder = "read,write"

################### DON'T CHANGE ANYTHING BELOW THIS LINE ###################
import mailstoreapi

# Connect to MailStore Management API
api = mailstoreapi.ManagementAPI(USER, PASSWORD, HOST, PORT)

# Walk through list of users
users = api.GetUserList()
for user in users:
    username = user["userName"]
    
    # Don't modify user admin
    if (username == "admin"):
        print("[SKIPPING] Not modifying user admin.")
        continue

    print("[UPDATING] " + username)

    # Set privileges
    api.SetUserPrivileges(userName=username, privileges=privileges)
    api.SetUserPrivilegesOnFolder(username, username, privilegesOnFolder)
